// src/index.ts
function vitePluginImplicitCssModules() {
  return {
    name: "vite-plugin-implicit-css-modules",
    transform(src, id) {
      if (!/(\.vue)(\?[\w|=|&]+)?$/i.test(id)) {
        return src;
      }
      const reg = /<style(?:\slang="\w+")?\s*module(=["']\w+["'])?>[^<]+<\/style>/gim;
      const styleCodes = [...src.matchAll(reg)];
      if (!styleCodes || !styleCodes.length) {
        return src;
      }
      styleCodes.forEach((styleCode) => {
        const moduleId = getModuleId(styleCode);
        const templateReg = /<template>[\s\S]*<\/template>/gim;
        const templateCode = src.match(templateReg);
        if (templateCode) {
          const resolved = resolveCssModules(
            styleCode[0],
            templateCode[0],
            moduleId
          );
          src = src.replace(templateReg, resolved);
        }
      });
      return src;
    }
  };
}
function resolveCssModules(style, template, moduleId) {
  let styleStr = style.replace(/\/\*[\s\S]*?\*\/|([^:]|^)\/\/.*$/gm, "");
  styleStr = styleStr.replace(/:global[^{]*/gim, "");
  const classReg = /(?<=\.).+(?=\s*{)/gim;
  let classNames = styleStr.match(classReg);
  if (!classNames) {
    return template;
  }
  classNames = classNames.map((item) => item.trim());
  let result = template;
  classNames.forEach((className) => {
    const reg = new RegExp(`class="\\s*${className}\\s*"`, "gim");
    result = result.replace(reg, `:class="${moduleId}['${className}']"`);
  });
  const multiClassNames = result.match(/(?<!:)class="\s*[^\s|"]+\s+[^"]*"/gim);
  if (!multiClassNames) {
    return result;
  }
  multiClassNames.forEach((str) => {
    const classNameStr = str.replace(/class="/gim, "").replace(/"/gim, "");
    let classNameArr = classNameStr.split(" ");
    const moduleClassNameArr = classNameArr.filter(
      (item) => (classNames || []).includes(item)
    );
    let moduleClassStr = "";
    if (moduleClassNameArr.length) {
      moduleClassStr = ':class="[';
      moduleClassStr += moduleClassNameArr.map((item) => `${moduleId}['${item}']`).join(",");
      moduleClassStr += ']"';
    }
    classNameArr = classNameArr.filter(
      (item) => !(classNames || []).includes(item) && item
    );
    let classStr = "";
    if (classNameArr.length) {
      classStr = ` class="${classNameArr.join(" ")}"`;
    }
    result = result.replace(str, `${moduleClassStr}${classStr}`);
  });
  return result;
}
function getModuleId(styleCode) {
  if (styleCode == null ? void 0 : styleCode[1]) {
    return styleCode[1].replace(/=/i, "").replace(/["']/gi, "");
  }
  return "$style";
}
export {
  vitePluginImplicitCssModules as default
};
